@@ -32,7 +32,7 @@ from calculate.lib.utils.ip import Pinger, IPError
 from calculate.lib.utils.files import (getModeFile, removeDir,
                                        pathJoin, tarLinks,
                                        listDirectory, process, find, STDOUT,
-                                       sambaPasswordCheck, checkUtils)
+                                       checkUtils)
 from calculate.lib.utils.samba import Samba, SambaError
 from calculate.lib.utils.mount import isMount
 from calculate.lib.utils.common import cmpVersion
@@ -1116,7 +1116,7 @@ class Client(commandServer, encrypt, Desktop):
             self.printERROR(_("Samba server not found in %s") % domain)
             return False
 
-    def getDomainPassword(self, domain):
+    def getDomainPassword(self, host):
         """
         Получить пароль для ввода в домен
         """
@@ -1131,9 +1131,12 @@ class Client(commandServer, encrypt, Desktop):
                 _("Domain password for the desktop"), False)
             self.printERROR(_("Wrong password"))
 
+        samba = Samba()
         for pwdRemote in passwdQueue():
             pwdRemote = pwdRemote or ""
-            if sambaPasswordCheck("client", pwdRemote, domain, "remote"):
+            domain = self.get_server_domainname(host)
+            if samba.password_check("client", pwdRemote, host, "remote",
+                                    domain):
                 self.clVars.Set('cl_remote_pw', pwdRemote)
                 return True
         return False
